==> tty-client-L0.08.tar.gz: tty-client-L0.08/cmd-pers.c <==
/*
 *  client/functions-pers.c
 *		The functions to actually execute the commands
 *		for the client.  Commands for handling
 *		persons.
 *
 *
 *  Copyright (C) 1990	Lysator Computer Club,
 *			Linkoping University,  Sweden
 *
 *  Everyone is granted permission to copy, modify and redistribute
 *  this code, provided the people they give it to can.
 *
 *
 *  Author:	Thomas Bellman
 *		Lysator Computer Club
 *		Linkoping University
 *		Sweden
 *
 *  email:	Bellman@Lysator.LiU.SE
 *
 *
 *  Any opinions expressed in this code are the author's PERSONAL opinions,
 *  and does NOT, repeat NOT, represent any official standpoint of Lysator,
 *  even if so stated.
 */



#include <stdio.h>
#include <time.h>
#include <string.h>

#include <config.h>
#include "config.h"

#include <kom-errno.h>
#include <kom-types.h>
#include <services.h>
#include <zmalloc.h>
#include <s-string.h>
#include <s-collat-tabs.h>

#include "copy.h"
#include "read-line.h"
#include "commands.h"
#include "parser.h"
#include "texts.h"
#include "edit.h"
#include "error.h"
#include "cache.h"
#include "quit.h"

#include "internal.h"
#include "cmds.h"


/* This is to emphasize that a function is exported. */
#define Export




/*
 *  The parameter 'ARGUMENT' in all the external functions, is a
 *  String containing the rest of the line, following the command.
 *  E g if the user gave the command "Skapa m|te Inl{gg }t mig",
 *  then the String "Inl{gg }t mig" is passed as the parameter
 *  'ARGUMENT' to the function responsible for the command 'skapa
 *  m|te'.  Leading and trailing spaces are skipped.  EMPTY_STRING
 *  is passed if no arguments to the command was given.
 */




/*  ==================================================================  */
/*		Internal functions for 'functions-*.c'			*/


/*
 *  Find all conferences matching the name NAME.  Also supports the
 *  notation "person nnn", where nnn is a number.
 */
Export  Pers_list
find_person_number (String	name)

{
#define FUNCTION "find_person_number()"

    Conf_list		  list_of_matches;
    u_short		  i;		/* Looping over conf_nos */
    u_short		  pno;		/* Counting pers_nos */
    Pers_list	 volatile result	= EMPTY_PERS_LIST;


#define CLEAN_UP()	do {				\
	release_conf_list (&list_of_matches);		} while (0)

    TOPLOOP_SETJMP();

    list_of_matches = find_conf_or_pers_no (name);

    /*  Transform the list of conferences into a list of persons,
     *  and remove all the matches that aren't persons.		*/

    /*  Allocate memory for the list of persons (might be a bit to
     *  large, though).						*/
    if ((result.persons = zmalloc (  list_of_matches.no_of_confs
				   * sizeof (Pers_no))) == NULL)
    {
	/* We need to increase the swap area, but we cant. */
	fatal (CLIENT_OUT_OF_MEMORY,
			    "Transforming conf list to persons",
			    0);
    }

    /*  Then copy the numbers of those that are persons  */
    for ( pno = i = 0 ;  i < list_of_matches.no_of_confs ;  i++ )
	if (list_of_matches.confs[i].type.letter_box == 1)
	    result.persons[pno++] = (Pers_no) list_of_matches.confs[i].conf_no;

    if (pno != 0)
	result.no_of_persons = pno;
    else
    {
	zfree (result.persons);
	result = EMPTY_PERS_LIST;
    }

    /* Phew! Finished at last. */
    RETURN (result);

#undef CLEAN_UP
#undef FUNCTION
}

==> tty-client-L0.09.tar.gz: tty-client-L0.09/cmd-pers.c <==
/*
 *  client/functions-pers.c
 *		The functions to actually execute the commands
 *		for the client.  Commands for handling
 *		persons.
 *
 *
 *  Copyright (C) 1990	Lysator Computer Club,
 *			Linkoping University,  Sweden
 *
 *  Everyone is granted permission to copy, modify and redistribute
 *  this code, provided the people they give it to can.
 *
 *
 *  Author:	Thomas Bellman
 *		Lysator Computer Club
 *		Linkoping University
 *		Sweden
 *
 *  email:	Bellman@Lysator.LiU.SE
 *
 *
 *  Any opinions expressed in this code are the author's PERSONAL opinions,
 *  and does NOT, repeat NOT, represent any official standpoint of Lysator,
 *  even if so stated.
 */



#include <stdio.h>
#include <time.h>
#include <string.h>

#include <config.h>
#include "config.h"

#include <kom-errno.h>
#include <kom-types.h>
#include <services.h>
#include <zmalloc.h>
#include <s-string.h>
#include <s-collat-tabs.h>

#include "copy.h"
#include "read-line.h"
#include "commands.h"
#include "parser.h"
#include "texts.h"
#include "edit.h"
#include "error.h"
#include "cache.h"
#include "quit.h"

#include "internal.h"
#include "cmds.h"


/* This is to emphasize that a function is exported. */
#define Export




/*
 *  The parameter 'ARGUMENT' in all the external functions, is a
 *  String containing the rest of the line, following the command.
 *  E g if the user gave the command "Skapa m|te Inl{gg }t mig",
 *  then the String "Inl{gg }t mig" is passed as the parameter
 *  'ARGUMENT' to the function responsible for the command 'skapa
 *  m|te'.  Leading and trailing spaces are skipped.  EMPTY_STRING
 *  is passed if no arguments to the command was given.
 */




/*  ==================================================================  */
/*		Internal functions for 'functions-*.c'			*/


/*
 *  Find all conferences matching the name NAME.  Also supports the
 *  notation "person nnn", where nnn is a number.
 */
Export  Pers_list
find_person_number (String	name)

{
#define FUNCTION "find_person_number()"

    Conf_list		  list_of_matches;
    u_short		  i;		/* Looping over conf_nos */
    u_short		  pno;		/* Counting pers_nos */
    Pers_list	 volatile result	= EMPTY_PERS_LIST;


#define CLEAN_UP()	do {				\
	release_conf_list (&list_of_matches);		} while (0)

    TOPLOOP_SETJMP();

    list_of_matches = find_conf_or_pers_no (name);

    /*  Transform the list of conferences into a list of persons,
     *  and remove all the matches that aren't persons.		*/

    /*  Allocate memory for the list of persons (might be a bit to
     *  large, though).						*/
    if ((result.persons = zmalloc (  list_of_matches.no_of_confs
				   * sizeof (Pers_no))) == NULL)
    {
	/* We need to increase the swap area, but we cant. */
	fatal1 (CLIENT_OUT_OF_MEMORY,
			    "Transforming conf list to persons");
    }

    /*  Then copy the numbers of those that are persons  */
    for ( pno = i = 0 ;  i < list_of_matches.no_of_confs ;  i++ )
	if (list_of_matches.confs[i].type.letter_box == 1)
	    result.persons[pno++] = (Pers_no) list_of_matches.confs[i].conf_no;

    if (pno != 0)
	result.no_of_persons = pno;
    else
    {
	zfree (result.persons);
	result = EMPTY_PERS_LIST;
    }

    /* Phew! Finished at last. */
    RETURN (result);

#undef CLEAN_UP
#undef FUNCTION
}
